export default {
    "index": 62,
    "lineNumber": 7,
    "column": 2,
    "message": "Redefinition of __proto__ property"
};